==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/UpdateHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UpdateHistoryFluentImpl<A extends UpdateHistoryFluent<A>> extends BaseFluent<A> implements UpdateHistoryFluent<A>{
  public UpdateHistoryFluentImpl() {
  }
  public UpdateHistoryFluentImpl(UpdateHistory instance) {
    this.withAcceptedRisks(instance.getAcceptedRisks()); 
    this.withCompletionTime(instance.getCompletionTime()); 
    this.withImage(instance.getImage()); 
    this.withStartedTime(instance.getStartedTime()); 
    this.withState(instance.getState()); 
    this.withVerified(instance.getVerified()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String acceptedRisks;
  private String completionTime;
  private String image;
  private String startedTime;
  private String state;
  private Boolean verified;
  private String version;
  private Map<String,Object> additionalProperties;
  public String getAcceptedRisks() {
    return this.acceptedRisks;
  }
  public A withAcceptedRisks(String acceptedRisks) {
    this.acceptedRisks=acceptedRisks; return (A) this;
  }
  public Boolean hasAcceptedRisks() {
    return this.acceptedRisks != null;
  }
  public String getCompletionTime() {
    return this.completionTime;
  }
  public A withCompletionTime(String completionTime) {
    this.completionTime=completionTime; return (A) this;
  }
  public Boolean hasCompletionTime() {
    return this.completionTime != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getStartedTime() {
    return this.startedTime;
  }
  public A withStartedTime(String startedTime) {
    this.startedTime=startedTime; return (A) this;
  }
  public Boolean hasStartedTime() {
    return this.startedTime != null;
  }
  public String getState() {
    return this.state;
  }
  public A withState(String state) {
    this.state=state; return (A) this;
  }
  public Boolean hasState() {
    return this.state != null;
  }
  public Boolean getVerified() {
    return this.verified;
  }
  public A withVerified(Boolean verified) {
    this.verified=verified; return (A) this;
  }
  public Boolean hasVerified() {
    return this.verified != null;
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpdateHistoryFluentImpl that = (UpdateHistoryFluentImpl) o;
    if (acceptedRisks != null ? !acceptedRisks.equals(that.acceptedRisks) :that.acceptedRisks != null) return false;
    if (completionTime != null ? !completionTime.equals(that.completionTime) :that.completionTime != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (startedTime != null ? !startedTime.equals(that.startedTime) :that.startedTime != null) return false;
    if (state != null ? !state.equals(that.state) :that.state != null) return false;
    if (verified != null ? !verified.equals(that.verified) :that.verified != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acceptedRisks,  completionTime,  image,  startedTime,  state,  verified,  version,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptedRisks != null) { sb.append("acceptedRisks:"); sb.append(acceptedRisks + ","); }
    if (completionTime != null) { sb.append("completionTime:"); sb.append(completionTime + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (startedTime != null) { sb.append("startedTime:"); sb.append(startedTime + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (verified != null) { sb.append("verified:"); sb.append(verified + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withVerified() {
    return withVerified(true);
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/UpdateHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UpdateHistoryFluentImpl<A extends UpdateHistoryFluent<A>> extends BaseFluent<A> implements UpdateHistoryFluent<A>{
  public UpdateHistoryFluentImpl() {
  }
  public UpdateHistoryFluentImpl(UpdateHistory instance) {
    if (instance != null) {
      this.withAcceptedRisks(instance.getAcceptedRisks());
      this.withCompletionTime(instance.getCompletionTime());
      this.withImage(instance.getImage());
      this.withStartedTime(instance.getStartedTime());
      this.withState(instance.getState());
      this.withVerified(instance.getVerified());
      this.withVersion(instance.getVersion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String acceptedRisks;
  private String completionTime;
  private String image;
  private String startedTime;
  private String state;
  private Boolean verified;
  private String version;
  private Map<String,Object> additionalProperties;
  public String getAcceptedRisks() {
    return this.acceptedRisks;
  }
  public A withAcceptedRisks(String acceptedRisks) {
    this.acceptedRisks=acceptedRisks; return (A) this;
  }
  public Boolean hasAcceptedRisks() {
    return this.acceptedRisks != null;
  }
  public String getCompletionTime() {
    return this.completionTime;
  }
  public A withCompletionTime(String completionTime) {
    this.completionTime=completionTime; return (A) this;
  }
  public Boolean hasCompletionTime() {
    return this.completionTime != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getStartedTime() {
    return this.startedTime;
  }
  public A withStartedTime(String startedTime) {
    this.startedTime=startedTime; return (A) this;
  }
  public Boolean hasStartedTime() {
    return this.startedTime != null;
  }
  public String getState() {
    return this.state;
  }
  public A withState(String state) {
    this.state=state; return (A) this;
  }
  public Boolean hasState() {
    return this.state != null;
  }
  public Boolean getVerified() {
    return this.verified;
  }
  public A withVerified(Boolean verified) {
    this.verified=verified; return (A) this;
  }
  public Boolean hasVerified() {
    return this.verified != null;
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateHistoryFluentImpl that = (UpdateHistoryFluentImpl) o;
    if (!java.util.Objects.equals(acceptedRisks, that.acceptedRisks)) return false;

    if (!java.util.Objects.equals(completionTime, that.completionTime)) return false;

    if (!java.util.Objects.equals(image, that.image)) return false;

    if (!java.util.Objects.equals(startedTime, that.startedTime)) return false;

    if (!java.util.Objects.equals(state, that.state)) return false;

    if (!java.util.Objects.equals(verified, that.verified)) return false;

    if (!java.util.Objects.equals(version, that.version)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acceptedRisks,  completionTime,  image,  startedTime,  state,  verified,  version,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptedRisks != null) { sb.append("acceptedRisks:"); sb.append(acceptedRisks + ","); }
    if (completionTime != null) { sb.append("completionTime:"); sb.append(completionTime + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (startedTime != null) { sb.append("startedTime:"); sb.append(startedTime + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (verified != null) { sb.append("verified:"); sb.append(verified + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withVerified() {
    return withVerified(true);
  }
  
}
